---
title: My first notes
date: 1989
---

# First notes

These are my first notes in this document

```python
def sayhello():
    s = 'Hello there'
    print(s)
```

Done.

<p>Paragraph tag section here.</p>
